# Relationship between coronavirus and Japanese industry

This project will compare amusement park sales with Internet industry sales and the number of people infected with COVID.

This is a line chart that uses new_confirmed_cases_daily.xlsx, park_sales.xlsx, and internet_service.xlsx.
The new_confirmed_cases_daily.xlsx, the park_sales.xlsx, the and internet_service.xlsx is downloadable from:

https://github.com/ritakei/industryandcovid/blob/main/newly_confirmed_cases_daily.xlsx
https://github.com/ritakei/industryandcovid/blob/main/internet_service_sales.xlsx
https://github.com/ritakei/VisitorsandCOVID/blob/main/park_sales.xlsx

The vertical axis is an integer and log display.

<img src='https://github.com/ritakei/industryandcovid/blob/main/industryandcovid.png?raw=true' width=640 height=480>

# How to install Visitors-and-Corona-Virus-Infected
You may need some libraries.

$ pip install matplotlib

$ pip install pandas

$ pip install openpyxl

# How to run Visitors-and-Corona-Virus-Infected
The VandC program allows you to plot the number of visitors to amusement parks in Japan and the number of people infected with COVID from January 2020 to April 2022.

$ pip install industryandcovid

$ industryandcovid

The following command can display a VisitorsandCOVID line graph with.
There are no options.
